# LedgerLinker Client

A syncronization client for the LedgerLinker service to sync your financial institution data with your plain text accounting ledger.

Learn more at https://www.ledgerlinker.com
